import java.awt.*;
import java.awt.event.*;
import java.sql.*;
import com.sun.java.swing.*;
// -> jdk1.2 imports
// import javax.swing.*;


public class SQLBuilder extends JPanel {
    static JFrame frame;
	static SQLBuilder panel ;

    static String metal= "Metal";
    static String metalClassName = "com.sun.java.swing.plaf.metal.MetalLookAndFeel";
//1.2	static String metalClassName = "javax.swing.plaf.metal.MetalLookAndFeel";
    static String motif = "Motif";
    static String motifClassName = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";

    static String windows = "Windows";
    static String windowsClassName = "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";

	static final int WIDTH = 640;
	static final int HEIGHT = 520;

    JRadioButton metalButton, motifButton, windowsButton;
	JTabbedPane				tabs;				// the main tabbed panel
	JLabel					statusBar;			// the status bar
	ConnectionPanel			connectPanel;		// the panel that handles connections
	QueryPanel				qPanel;				// panel where queries are done
	dbmdPanel				dbmd;				// displays the database meta data
	rsmdPanel				rsmd;				// displays the ResultSet meta data

	/**
	 *
	 */
	JRadioButton addButton (String label, char mnemonic, ButtonGroup g, String command, ActionListener a) {
		JRadioButton b = new JRadioButton (label);
		b.setMnemonic (mnemonic);
		b.setActionCommand (command);
		g.add (b);
		add(b);
		b.addActionListener (a);
		return b;
	} // method addButton

	/**
	 * Accessor for statusBar.
	 */
	JLabel getStatusBar () {
		return statusBar;
	} // method getStatusBar

	/**
	 * accessor for frame.
	 */
	JFrame getFrame () {
		return frame;
	} // method getFrame


	/**
	 * Invoked by the connection panel when a connection
	 * is made to the database.
	 */
	void onConnect (Connection c) {
		qPanel.onConnect (c);
		dbmd.onConnect(c);
	} // method onConnect

	/**
	 * Invoked by the query panel when a query completes.
	 */
	void onQuery (ResultSet r) {
		rsmd.onQuery (r);
	} // method onQuery


    public SQLBuilder() {
		// Create the buttons.
		ButtonGroup group = new ButtonGroup();
		RadioListener myListener = new RadioListener();
		statusBar = new JLabel ("Disconnected");

		metalButton = addButton (metal, 'o', group, metalClassName, myListener);
		motifButton = addButton (motif, 'm', group, motifClassName, myListener);
		windowsButton = addButton (windows, 'w', group, windowsClassName, myListener);

		tabs = new JTabbedPane ();
		connectPanel = new ConnectionPanel(this);
		dbmd = new dbmdPanel (this);
		qPanel = new QueryPanel(this);
		rsmd = new rsmdPanel (this);
		tabs.addTab ("Connection",null,connectPanel,"Connects/Disconnects to a database");
		tabs.addTab ("Dbase Data",null,dbmd,"Database Meta-data");
		tabs.addTab ("Query",null,qPanel,"Performs database queries");
		tabs.addTab ("Results Data",null,rsmd,"Result Set Meta-data");

		tabs.setSelectedIndex(0);
    }


    /** An ActionListener that listens to the radio buttons. */
    class RadioListener implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			String lnfName = e.getActionCommand();
			try {
				UIManager.setLookAndFeel(lnfName);
				SwingUtilities.updateComponentTreeUI(frame);
				frame.setSize(WIDTH, HEIGHT);
				//frame.pack();
			} catch (Exception exc) {
				JRadioButton button = (JRadioButton)e.getSource();
				button.setEnabled(false);
				updateState();
				System.err.println("Could not load LookAndFeel: " + lnfName);
			}
		} // actionPerformed
	} // class RadioListener 

    public void updateState() {
		String lnfName = UIManager.getLookAndFeel().getClass().getName();
		if (lnfName.indexOf(metal) >= 0) {
			metalButton.setSelected(true);
		} else if (lnfName.indexOf(windows) >= 0) {
			windowsButton.setSelected(true);
		} else if (lnfName.indexOf(motif) >= 0) {
			motifButton.setSelected(true);
		} else {
			System.err.println("SimpleExample if using an unknown L&F: " + lnfName);
		}
    }



    public static void main(String s[]) {

		frame = new JFrame("ICS SQLBuilder");
		panel = new SQLBuilder();
		
		frame.addWindowListener(new WindowEventHandler(panel));
		frame.getContentPane().add("North", panel);
		frame.getContentPane().add("Center", panel.tabs);
		frame.getContentPane().add("South", panel.statusBar);
		frame.setSize(WIDTH,HEIGHT);
		frame.setVisible(true);
		
		panel.updateState();
    }
}

class WindowEventHandler extends WindowAdapter {

	SQLBuilder	panel;

	WindowEventHandler (SQLBuilder sqlbuild) {
		panel = sqlbuild;
	} // method WindowEventHandler

	public void windowClosing(WindowEvent e) {
		try {
			panel.connectPanel.onDisconnect();
		} catch (Exception ex) {
			System.out.println ("Error disconnecting: "+ex.toString());
		} // try-catch
		System.exit(0);
	}
} // class WindowEventHandler 